module MkGreenwich
  module Const
    MSG_ERR_1 = "[ERROR] Format: YYYYMMDD or YYYYMMDDHHMMSS"
    MSG_ERR_2 = "[ERROR] Invalid date-time!"
    J2000   = 2451545.0  # Reference epoch (J2000.0), Julian Date
    JC      = 36525.0    # Days per Julian century
    # ==== for CipCio ====
    # Polynomial coefficients
    SP = [94.00e-6, 3808.65e-6, -122.68e-6, -72574.11e-6, 27.98e-6, 15.62e-6]
    # Terms of order t^0
    S_0 = [
      [[0,  0,  0,  0,  1,  0,  0,  0], -2640.73e-6,  0.39e-6],
      [[0,  0,  0,  0,  2,  0,  0,  0],   -63.53e-6,  0.02e-6],
      [[0,  0,  2, -2,  3,  0,  0,  0],   -11.75e-6, -0.01e-6],
      [[0,  0,  2, -2,  1,  0,  0,  0],   -11.21e-6, -0.01e-6],
      [[0,  0,  2, -2,  2,  0,  0,  0],     4.57e-6,  0.00e-6],
      [[0,  0,  2,  0,  3,  0,  0,  0],    -2.02e-6,  0.00e-6],
      [[0,  0,  2,  0,  1,  0,  0,  0],    -1.98e-6,  0.00e-6],
      [[0,  0,  0,  0,  3,  0,  0,  0],     1.72e-6,  0.00e-6],
      [[0,  1,  0,  0,  1,  0,  0,  0],     1.41e-6,  0.01e-6],
      [[0,  1,  0,  0, -1,  0,  0,  0],     1.26e-6,  0.01e-6],
      [[1,  0,  0,  0, -1,  0,  0,  0],     0.63e-6,  0.00e-6],
      [[1,  0,  0,  0,  1,  0,  0,  0],     0.63e-6,  0.00e-6],
      [[0,  1,  2, -2,  3,  0,  0,  0],    -0.46e-6,  0.00e-6],
      [[0,  1,  2, -2,  1,  0,  0,  0],    -0.45e-6,  0.00e-6],
      [[0,  0,  4, -4,  4,  0,  0,  0],    -0.36e-6,  0.00e-6],
      [[0,  0,  1, -1,  1, -8, 12,  0],     0.24e-6,  0.12e-6],
      [[0,  0,  2,  0,  0,  0,  0,  0],    -0.32e-6,  0.00e-6],
      [[0,  0,  2,  0,  2,  0,  0,  0],    -0.28e-6,  0.00e-6],
      [[1,  0,  2,  0,  3,  0,  0,  0],    -0.27e-6,  0.00e-6],
      [[1,  0,  2,  0,  1,  0,  0,  0],    -0.26e-6,  0.00e-6],
      [[0,  0,  2, -2,  0,  0,  0,  0],     0.21e-6,  0.00e-6],
      [[0,  1, -2,  2, -3,  0,  0,  0],    -0.19e-6,  0.00e-6],
      [[0,  1, -2,  2, -1,  0,  0,  0],    -0.18e-6,  0.00e-6],
      [[0,  0,  0,  0,  0,  8,-13, -1],     0.10e-6, -0.05e-6],
      [[0,  0,  0,  2,  0,  0,  0,  0],    -0.15e-6,  0.00e-6],
      [[2,  0, -2,  0, -1,  0,  0,  0],     0.14e-6,  0.00e-6],
      [[0,  1,  2, -2,  2,  0,  0,  0],     0.14e-6,  0.00e-6],
      [[1,  0,  0, -2,  1,  0,  0,  0],    -0.14e-6,  0.00e-6],
      [[1,  0,  0, -2, -1,  0,  0,  0],    -0.14e-6,  0.00e-6],
      [[0,  0,  4, -2,  4,  0,  0,  0],    -0.13e-6,  0.00e-6],
      [[0,  0,  2, -2,  4,  0,  0,  0],     0.11e-6,  0.00e-6],
      [[1,  0, -2,  0, -3,  0,  0,  0],    -0.11e-6,  0.00e-6],
      [[1,  0, -2,  0, -1,  0,  0,  0],    -0.11e-6,  0.00e-6]
    ]
    # Terms of order t^1
    S_1 = [
      [[0,  0,  0,  0,  2,  0,  0,  0], -0.07e-6,  3.57e-6],
      [[0,  0,  0,  0,  1,  0,  0,  0],  1.73e-6, -0.03e-6],
      [[0,  0,  2, -2,  3,  0,  0,  0],  0.00e-6,  0.48e-6]
    ]
    # Terms of order t^2
    S_2 = [
      [[0,  0,  0,  0,  1,  0,  0,  0], 743.52e-6, -0.17e-6],
      [[0,  0,  2, -2,  2,  0,  0,  0],  56.91e-6,  0.06e-6],
      [[0,  0,  2,  0,  2,  0,  0,  0],   9.84e-6, -0.01e-6],
      [[0,  0,  0,  0,  2,  0,  0,  0],  -8.85e-6,  0.01e-6],
      [[0,  1,  0,  0,  0,  0,  0,  0],  -6.38e-6, -0.05e-6],
      [[1,  0,  0,  0,  0,  0,  0,  0],  -3.07e-6,  0.00e-6],
      [[0,  1,  2, -2,  2,  0,  0,  0],   2.23e-6,  0.00e-6],
      [[0,  0,  2,  0,  1,  0,  0,  0],   1.67e-6,  0.00e-6],
      [[1,  0,  2,  0,  2,  0,  0,  0],   1.30e-6,  0.00e-6],
      [[0,  1, -2,  2, -2,  0,  0,  0],   0.93e-6,  0.00e-6],
      [[1,  0,  0, -2,  0,  0,  0,  0],   0.68e-6,  0.00e-6],
      [[0,  0,  2, -2,  1,  0,  0,  0],  -0.55e-6,  0.00e-6],
      [[1,  0, -2,  0, -2,  0,  0,  0],   0.53e-6,  0.00e-6],
      [[0,  0,  0,  2,  0,  0,  0,  0],  -0.27e-6,  0.00e-6],
      [[1,  0,  0,  0,  1,  0,  0,  0],  -0.27e-6,  0.00e-6],
      [[1,  0, -2, -2, -2,  0,  0,  0],  -0.26e-6,  0.00e-6],
      [[1,  0,  0,  0, -1,  0,  0,  0],  -0.25e-6,  0.00e-6],
      [[1,  0,  2,  0,  1,  0,  0,  0],   0.22e-6,  0.00e-6],
      [[2,  0,  0, -2,  0,  0,  0,  0],  -0.21e-6,  0.00e-6],
      [[2,  0, -2,  0, -1,  0,  0,  0],   0.20e-6,  0.00e-6],
      [[0,  0,  2,  2,  2,  0,  0,  0],   0.17e-6,  0.00e-6],
      [[2,  0,  2,  0,  2,  0,  0,  0],   0.13e-6,  0.00e-6],
      [[2,  0,  0,  0,  0,  0,  0,  0],  -0.13e-6,  0.00e-6],
      [[1,  0,  2, -2,  2,  0,  0,  0],  -0.12e-6,  0.00e-6],
      [[0,  0,  2,  0,  0,  0,  0,  0],  -0.11e-6,  0.00e-6]
    ]
    # Terms of order t^3
    S_3 = [
      [[0,  0,  0,  0,  1,  0,  0,  0],  0.30e-6, -23.42e-6],
      [[0,  0,  2, -2,  2,  0,  0,  0], -0.03e-6,  -1.46e-6],
      [[0,  0,  2,  0,  2,  0,  0,  0], -0.01e-6,  -0.25e-6],
      [[0,  0,  0,  0,  2,  0,  0,  0],  0.00e-6,   0.23e-6]
    ]
    # Terms of order t^4
    S_4 = [
      [[0,  0,  0,  0,  1,  0,  0,  0], -0.26e-6, -0.01e-6]
    ]
    AS2R    = 4.848136811095359935899141e-6  # Arcseconds to radians
    PI      = 3.141592653589793238462643     # PI
    PI2     = 6.283185307179586476925287     # 2 * PI
    PI_180  = 0.017453292519943295           # PI / 180
    TURNAS  = 1296000.0                      # Arcseconds in a full circle
  end
end
